FileRecorder

Struct FileRecorder 

pub struct FileRecorder<'a> {
    pub last_rn: u32,
    /* private fields */
}
recorder for one file

Fields

last_rn: u32

number of the last record written (relative to the first_rec_num)

Implementations

Source

impl<'a> FileRecorder<'_>

pub fn new( path: &Path, first_rec_num: u64, max_num_segments: u32, max_nrps: u32, ) -> Result<Self>

Create a new file recorder

Arguments
  • path - The path of the file to be recorded.
  • first_rec_num - The first record number. Al the record numbers in the file are relative to this one
  • max_num_seg - The maximum number of segments that can be stored in the file. This determines the size of the header
  • max_nrps - The maximum number of records per segment
pub fn append(&mut self, rn: u64, msg: &[u8], is_pdef: bool) -> Result<()>

append the record to the end of the file

pub fn is_full(&self) -> bool

pub fn flush(&mut self) -> Result<()>